#!/usr/bin/perl
#
# Read a csv file in the format of oldUserid, newUserid
# And instruct the Cisco UCM to update the end user profile of oldUserid to now use newUserid instead.
# 
# ajp26  , 7/27/2016
#

use warnings;
use strict;
use SOAP::Lite;

$SOAP::Constants::PREFIX_ENV = "soapenv";

my $cmUser = 'netman';
my $cmPass = '10twenty';

my $ucm = new SOAP::Lite
        uri => 'http://www.cisco.com/AXL/API/10.0',
        ns => 'http://www.cisco.com/AXL/API/10.0',
	proxy => 'https://publisher.cit.buffalo.edu:8443/axl/',
;

$ucm -> on_action( sub { join ' ', @_ } );
$ucm -> on_action(sub { '"CUCM:DB ver=10.0 ' . $_[1] . '"' });

open my $csv_file, "user_munge.csv" or die $!;
open my $log_file, ">>", "user_results.txt" or die $!;

my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) =  localtime;
my $record_count = 0;

print $log_file "--Username munge process started! $mon/$mday/$year $hour:$min:$sec---\n";

while (<$csv_file>) {

	$record_count++;

	my ($oldUserid, $newUserid) = split(/,/);	
	$oldUserid =~ s/^\s+|\s+$oldUserid//g;
	$newUserid =~ s/^\s+|\s+$newUserid//g;
	$oldUserid =~ s/\n//g;
	$newUserid =~ s/\n//g;
	$oldUserid =~ s/\r//g;
	$newUserid =~ s/\r//g;

	my $envelope =  SOAP::Data->name('UpdateUserReq' => 

		SOAP::Data->value(
 			SOAP::Data->name('userid' => $oldUserid),
			SOAP::Data->name('newUserid' => $newUserid)
			),
		);


	my $result = $ucm->updateUser($envelope);

	unless ($result->fault) {
	  print $log_file "Processing $oldUserid munge to $newUserid: SUCCESS\n";
	} else {
	  print $log_file "Processing $oldUserid munge to $newUserid: FAIL:  " . $result->faultstring . "\n";
	}

}

close $csv_file or die $!;
print $log_file "Completed $record_count records!\n";
close $log_file or die $!;

# Override the SOAP auth function to pass our credentials
sub SOAP::Transport::HTTP::Client::get_basic_credentials {
    return ( $cmUser => $cmPass );
}
